@@ -136,7 +136,7 @@ ggemmeans <- function(model,
   attr(result, "model.name") <- model_name
 
   # add raw data as well
-  attr(result, "rawdata") <- .get_raw_data(model, original_model_frame, cleaned_terms, back.transform)
+  attr(result, "rawdata") <- .get_raw_data(model, original_model_frame, cleaned_terms)
 
   .post_processing_labels(
     model = model,
