@@ -1,7 +1,6 @@
 # return levels, as list
 # c("age", "edu [1,3]", "sex [2]") would return a list:
 # $edu [1] 1 3; $sex [1] 2
-#' @importFrom purrr possibly
 #' @importFrom stats setNames sd
 #' @importFrom sjlabelled as_numeric
 .get_representative_values <- function(x, model_frame = NULL) {
@@ -28,7 +27,7 @@
   at_pattern <- c("minmax", "meansd", "zeromax", "quart2", "all", "quart")
 
   # now check for ranges
-  at_levels <- purrr::map2(at_levels, at_terms, function(x, y) {
+  at_levels <- mapply(function(x, y) {
 
     # Here we may have a range of values. we then create the
     # sequence with all values from this range
@@ -41,6 +40,8 @@
       if (grepl("by", s[2], fixed = TRUE)) {
         from_to_by[2] <- sub("(.*)(\\s*)by(\\s*)=(.*)", "\\1", x = s[2])
         from_to_by[3] <- sub("(.*)(\\s*)by(\\s*)=(.*)", "\\4", x = s[2])
+      } else if (grepl("by", s[3], fixed = TRUE)) {
+        from_to_by[3] <- sub("by(\\s*)=(.*)", "\\2", x = s[3])
       } else {
         from_to_by[3] <- "1"
       }
@@ -86,20 +87,42 @@
       # valid function name. In this case, simply return the label.
 
       if (x == "pretty") {
+        # return pretty range
         x <- pretty_range(model_frame[[y]])
       } else if (x %in% at_pattern) {
+        # return at specific values
         x <- values_at(model_frame[[y]], values = x)
       } else {
-        at_function <- purrr::possibly(match.fun, NULL)
-        funtrans <- at_function(x)
-        if (!is.null(funtrans) && !is.null(model_frame)) {
+
+        # transform values by function
+        funtrans <- try(match.fun(x), silent = TRUE)
+        if (!inherits(funtrans, "try-error") && !is.null(model_frame)) {
           x <- funtrans(sort(unique(model_frame[[y]])))
+
+          # is x a value from vector?
+        } else if (x %in% unique(model_frame[[y]])) {
+          x
+
+          # return values of a vector
+        } else {
+          x <- tryCatch({
+            get(x, envir = parent.frame())
+          }, error = function(e) {
+            NULL
+          })
+          if (is.null(x)) {
+            x <- tryCatch({
+              get(x, envir = globalenv())
+            }, error = function(e) {
+              NULL
+            })
+          }
         }
       }
     }
 
     x
-  })
+  }, at_levels, at_terms, SIMPLIFY = FALSE)
 
   # check if levels were numeric or not...
   suppressWarnings(
