@@ -4,8 +4,6 @@ if (suppressWarnings(
   require("survival")
 )) {
 
-  context("ggeffects, survreg")
-
   data("ovarian")
   m1 <- survreg(Surv(futime, fustat) ~ ecog.ps + rx, data = ovarian, dist = "exponential")
 
@@ -15,7 +13,7 @@ if (suppressWarnings(
   })
 
   test_that("ggeffect, survreg", {
-    expect_error(ggeffect(m1, "ecog.ps"))
+    expect_null(ggeffect(m1, "ecog.ps"))
   })
 
   test_that("ggemmeans, survreg", {
